Test Alert Verifification

Test Alert verifyment
open | ../tests/html/test_verify_alert.html |
verifyAlertNotPresent |  |
assertAlertNotPresent |  |
click | oneAlert |
verifyAlertPresent |  |
waitForAlertPresent |  |
assertAlertPresent |  |
verifyAlert | Store Below 494 degrees K! |
click | oneAlert |
storeAlert | myVar |
verifyExpression | ${myVar} | Store Below 494 degrees K!
click | twoAlerts |
verifyAlert | * 220 degrees C! |
verifyAlert | regexp:^Store Below 429 degrees F! |
clickAndWait | alertAndLeave |
verifyAlert | I'm Melting! I'm Melting! |
open | ../tests/html/test_verify_alert.html |
assertFailureOnNext | There were no alerts |
verifyAlert | noAlert |
click | oneAlert |
assertFailureOnNext | Actual value 'Store Below 494 degrees K!' did not match 'wrongAlert' |
verifyAlert | wrongAlert |
click | twoAlerts |
assertFailureOnNext | Actual value 'Store Below 220 degrees C!' did not match 'Store Below 429 degrees F!' |
verifyAlert | Store Below 429 degrees F! |
assertFailureOnNext | Actual value 'Store Below 429 degrees F!' did not match 'Store Below 220 degrees C!' |
verifyAlert | Store Below 220 degrees C! |
click | oneAlert |
assertErrorOnNext | There was an unexpected Alert! [Store Below 494 degrees K!] |
open | ../tests/html/test_verify_alert.html |